@@ -22,6 +22,7 @@ from pycha.bar import HorizontalBarChart, VerticalBarChart
 from pycha.line import LineChart
 from pycha.pie import PieChart
 from pycha.scatter import ScatterplotChart
+from pycha.stackedbar import StackedVerticalBarChart, StackedHorizontalBarChart
 
 from chavier.gui import GUI
 
@@ -34,13 +35,17 @@ class App(object):
         LineChart,
         PieChart,
         ScatterplotChart,
+        StackedVerticalBarChart,
+        StackedHorizontalBarChart,
         )
 
     (VERTICAL_BAR_TYPE,
      HORIZONTAL_BAR_TYPE,
      LINE_TYPE,
      PIE_TYPE,
-     SCATTER_TYPE) = range(len(CHART_TYPES))
+     SCATTER_TYPE,
+     STACKED_VERTICAL_BAR_TYPE,
+     STACKED_HORIZONTAL_BAR_TYPE) = range(len(CHART_TYPES))
 
     OPTIONS_TYPES = dict(
         axis=dict(
@@ -51,6 +56,8 @@ class App(object):
             labelFont=str,
             labelFontSize=int,
             labelWidth=float,
+            tickFont=str,
+            tickFontSize=int,
             x=dict(
                 hide=bool,
                 ticks=list,
@@ -59,6 +66,7 @@ class App(object):
                 range=list,
                 rotate=float,
                 label=unicode,
+                interval=int,
                 ),
             y=dict(
                 hide=bool,
@@ -68,6 +76,7 @@ class App(object):
                 range=list,
                 rotate=float,
                 label=unicode,
+                interval=int,
                 ),
             ),
         background=dict(
@@ -110,7 +119,13 @@ class App(object):
         shouldFill=bool,
         barWidthFillFraction=float,
         pieRadius=float,
-        colorScheme=str,
+        colorScheme=dict(
+            name=str,
+            args=dict(
+                initialColor=str,
+                colors=list,
+                ),
+            ),
         title=unicode,
         titleFont=str,
         titleFontSize=int,
