@@ -16,12 +16,12 @@
 # along with PyCha.  If not, see <http://www.gnu.org/licenses/>.
 
 import copy
+import inspect
 import math
 
 import cairo
 
-from pycha.color import (defaultColorscheme, getColorscheme, hex2rgb,
-                         DEFAULT_COLOR)
+from pycha.color import ColorScheme, hex2rgb, DEFAULT_COLOR
 
 
 class Chart(object):
@@ -56,6 +56,8 @@ class Chart(object):
         # initialize the surface
         self._initSurface(surface)
 
+        self.colorScheme = None
+
     def addDataset(self, dataset):
         """Adds an object containing chart data to the storage hash"""
         self.datasets += dataset
@@ -112,18 +114,20 @@ class Chart(object):
         cx.restore()
 
     def _setColorscheme(self):
-        """Sets the colorScheme used for the chart using the color in the
+        """Sets the colorScheme used for the chart using the
         options.colorScheme option
         """
-        scheme = self.options.colorScheme
+        name = self.options.colorScheme.name
         keys = self._getDatasetsKeys()
-        if isinstance(scheme, dict):
-            if not scheme:
-                self.options.colorScheme = defaultColorscheme(keys)
-        elif isinstance(scheme, basestring):
-            self.options.colorScheme = getColorscheme(scheme, keys)
-        else:
-            raise TypeError("Color scheme is invalid!")
+        colorSchemeClass = ColorScheme.getColorScheme(name, None)
+        if colorSchemeClass is None:
+            raise ValueError('Color scheme "%s" is invalid!' % name)
+
+        # Remove invalid args before calling the constructor
+        kwargs = dict(self.options.colorScheme.args)
+        validArgs = inspect.getargspec(colorSchemeClass.__init__)[0]
+        kwargs = dict([(k, v) for k, v in kwargs.items() if k in validArgs])
+        self.colorScheme = colorSchemeClass(keys, **kwargs)
 
     def _initSurface(self, surface):
         self.surface = surface
@@ -222,6 +226,15 @@ class Chart(object):
                 if 0.0 <= pos <= 1.0:
                     self.xticks.append((pos, label))
 
+        elif self.options.axis.x.interval > 0:
+            interval = self.options.axis.x.interval
+            label = (divmod(self.minxval, interval)[0] + 1) * interval
+            pos = self.xscale * (label - self.minxval)
+            while 0.0 <= pos <= 1.0:
+                self.xticks.append((pos, label))
+                label += interval
+                pos = self.xscale * (label - self.minxval)
+
         elif self.options.axis.x.tickCount > 0:
             uniqx = range(len(uniqueIndices(stores)) + 1)
             roughSeparation = self.xrange / self.options.axis.x.tickCount
@@ -248,6 +261,15 @@ class Chart(object):
                 if 0.0 <= pos <= 1.0:
                     self.yticks.append((pos, label))
 
+        elif self.options.axis.y.interval > 0:
+            interval = self.options.axis.y.interval
+            label = (divmod(self.minyval, interval)[0] + 1) * interval
+            pos = 1.0 - (self.yscale * (label - self.minyval))
+            while 0.0 <= pos <= 1.0:
+                self.yticks.append((pos, label))
+                label += interval
+                pos = 1.0 - (self.yscale * (label - self.minyval))
+
         elif self.options.axis.y.tickCount > 0:
             prec = self.options.axis.y.tickPrecision
             num = self.yrange / self.options.axis.y.tickCount
@@ -327,6 +349,11 @@ class Chart(object):
         cx.close_path()
         cx.stroke()
 
+        cx.select_font_face(self.options.axis.tickFont,
+                            cairo.FONT_SLANT_NORMAL,
+                            cairo.FONT_WEIGHT_NORMAL)
+        cx.set_font_size(self.options.axis.tickFontSize)
+
         label = unicode(tick[1])
         extents = cx.text_extents(label)
         labelWidth = extents[2]
@@ -362,6 +389,11 @@ class Chart(object):
         cx.close_path()
         cx.stroke()
 
+        cx.select_font_face(self.options.axis.tickFont,
+                            cairo.FONT_SLANT_NORMAL,
+                            cairo.FONT_WEIGHT_NORMAL)
+        cx.set_font_size(self.options.axis.tickFontSize)
+
         label = unicode(tick[1])
         extents = cx.text_extents(label)
         labelWidth = extents[2]
@@ -551,7 +583,7 @@ class Chart(object):
 
         def drawKey(key, x, y, text_height):
             cx.rectangle(x, y, bullet, bullet)
-            cx.set_source_rgb(*self.options.colorScheme[key])
+            cx.set_source_rgb(*self.colorScheme[key])
             cx.fill_preserve()
             cx.set_source_rgb(0, 0, 0)
             cx.stroke()
@@ -615,6 +647,8 @@ DEFAULT_OPTIONS = Option(
         labelFont='Tahoma',
         labelFontSize=9,
         labelWidth=50.0,
+        tickFont='Tahoma',
+        tickFontSize=9,
         x=Option(
             hide=False,
             ticks=None,
@@ -623,6 +657,7 @@ DEFAULT_OPTIONS = Option(
             range=None,
             rotate=None,
             label=None,
+            interval=0,
         ),
         y=Option(
             hide=False,
@@ -632,6 +667,7 @@ DEFAULT_OPTIONS = Option(
             range=None,
             rotate=None,
             label=None,
+            interval=0,
         ),
     ),
     background=Option(
@@ -669,7 +705,13 @@ DEFAULT_OPTIONS = Option(
     shouldFill=True,
     barWidthFillFraction=0.75,
     pieRadius=0.4,
-    colorScheme=DEFAULT_COLOR,
+    colorScheme=Option(
+        name='gradient',
+        args=Option(
+            initialColor=DEFAULT_COLOR,
+            colors=None,
+            ),
+    ),
     title=None,
     titleFont='Tahoma',
     titleFontSize=12,
